@@ -16,13 +16,10 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function, absolute_import
-
 import collections
 
 import numpy as N
 from .. import qtall as qt
-from ..compat import citems, cvalues
 from .. import document
 from .. import datasets
 from . import base
@@ -65,7 +62,7 @@ class ImportParamsFITS(base.ImportParamsBase):
         'twodranges': None,
         'twod_as_oned': None,
         'wcsmodes': None,
-        }
+    }
     defaults.update(base.ImportParamsBase.defaults)
 
 class LinkedFileFITS(base.LinkedFileBase):
@@ -156,9 +153,11 @@ class OperationDataImportFITS(base.OperationDataImportBase):
             mode = attr['wcsmode']
 
         # standard linear wcs keywords
-        wcs = [hdu.header.get(x, None) for x in (
-            'CRVAL1', 'CRPIX1', 'CDELT1',
-            'CRVAL2', 'CRPIX2', 'CDELT2')]
+        wcs = [
+            hdu.header.get(x, None) for x in (
+                'CRVAL1', 'CRPIX1', 'CDELT1',
+                'CRVAL2', 'CRPIX2', 'CDELT2')
+        ]
 
         if mode == "pixel" or (None in wcs and "wcs" in mode):
             rangex = rangey = None
@@ -293,13 +292,15 @@ class OperationDataImportFITS(base.OperationDataImportBase):
         if data.ndim == 1:
             # Standard 1D Import
             # handle any possible error bars
-            args = { 'data': data,
-                     'serr': errordatasets[name]['+-'],
-                     'nerr': errordatasets[name]['-'],
-                     'perr': errordatasets[name]['+'] }
+            args = {
+                'data': data,
+                'serr': errordatasets[name]['+-'],
+                'nerr': errordatasets[name]['-'],
+                'perr': errordatasets[name]['+'] 
+            }
 
             # find minimum length and cut down if necessary
-            minlen = min([len(d) for d in cvalues(args)
+            minlen = min([len(d) for d in args.values()
                           if d is not None])
             for a in list(args):
                 if args[a] is not None and len(args[a]) > minlen:
@@ -328,8 +329,9 @@ class OperationDataImportFITS(base.OperationDataImportBase):
                     r = dread.options["range"]
                     attrs["xrange"] = (r[0], r[2])
                     attrs["yrange"] = (r[1], r[3])
-                for attr in ("xrange", "yrange", "xcent", "ycent",
-                             "xedge", "yedge"):
+                for attr in (
+                        "xrange", "yrange", "xcent", "ycent",
+                        "xedge", "yedge" ):
                     if attr in dread.options:
                         attrs[attr] = dread.options.get(attr)
 
@@ -371,7 +373,7 @@ class OperationDataImportFITS(base.OperationDataImportBase):
             linkedfile = None
 
         # create the veusz output datasets
-        for name, dread in citems(dsread):
+        for name, dread in dsread.items():
             if isinstance(dread.data, N.ndarray):
                 # numeric
                 ds = self.numericDataToDataset(name, dread, errordatasets)
@@ -464,7 +466,7 @@ def ImportFileFITS(
       KEY=VALUE
     or for column-specific values
       COLUMNNAME: KEY=VALUE
- 
+
     Returns: list of imported datasets
 
     """
@@ -552,7 +554,7 @@ def ImportFITSFile(comm, dsname, filename, hdu,
             renames=renames,
             wcsmodes={fullname: wcsmode},
             linked=linked,
-            )
+        )
 
     else:
         # handle tables
@@ -584,7 +586,7 @@ def ImportFITSFile(comm, dsname, filename, hdu,
             namemap=namemap,
             renames=renames,
             linked=linked,
-            )
+        )
 
 # new import command
 document.registerImportCommand("ImportFileFITS", ImportFileFITS)
