@@ -18,8 +18,6 @@
 
 """Dataset creation dialog for 2d data."""
 
-from __future__ import division
-from ..compat import crange, citems, cstr
 from .. import qtall as qt
 from .. import utils
 from .. import document
@@ -62,8 +60,10 @@ class DataCreate2DDialog(VeuszDialog):
 
         document.signalModified.connect(self.updateDatasetLists)
 
-        for combo in (self.namecombo, self.xexprcombo, self.yexprcombo,
-                      self.zexprcombo):
+        for combo in (
+                self.namecombo, self.xexprcombo, self.yexprcombo,
+                self.zexprcombo
+        ):
             combo.editTextChanged.connect(self.enableDisableCreate)
 
         self.fromxyzexpr.toggle()
@@ -83,7 +83,7 @@ class DataCreate2DDialog(VeuszDialog):
     def escapeDatasets(self, dsnames):
         """Escape dataset names if they are not typical python ones."""
 
-        for i in crange(len(dsnames)):
+        for i in range(len(dsnames)):
             if not utils.validPythonIdentifier(dsnames[i]):
                 dsnames[i] = '`%s`' % dsnames[i]
 
@@ -92,7 +92,7 @@ class DataCreate2DDialog(VeuszDialog):
 
         # get list of 1d and 2d numeric datasets
         datasets = [[],[]]
-        for name, ds in citems(self.document.data):
+        for name, ds in self.document.data.items():
             if ds.datatype == 'numeric':
                 datasets[ds.dimensions-1].append(name)
         datasets[0].sort()
@@ -175,8 +175,10 @@ class DataCreate2DDialog(VeuszDialog):
 
         elif self.mode == 'xyfunc':
             # need x and yexpr in special step format min:max:step
-            disable = disable or ( checkGetStep(text['xexpr']) is None or
-                                   checkGetStep(text['yexpr']) is None )
+            disable = disable or (
+                checkGetStep(text['xexpr']) is None or
+                checkGetStep(text['yexpr']) is None
+            )
 
         # finally check button
         self.createbutton.setDisabled(disable)
@@ -225,7 +227,7 @@ class DataCreate2DDialog(VeuszDialog):
                 datasets.DatasetException) as e:
 
             msg = _("Failed to create dataset '%s'") % text['name']
-            s = cstr(e)
+            s = str(e)
             if s:
                 msg += ' (%s)' % s
         else:
