@@ -20,12 +20,9 @@
 
 """Dialog for reloading linked data."""
 
-from __future__ import division
 import os
 
-from ..compat import cstr
 from .. import qtall as qt
-from .. import document
 from .veuszdialog import VeuszDialog
 
 def _(text, disambiguation=None, context="ReloadDialog"):
@@ -113,7 +110,7 @@ class ReloadData(VeuszDialog):
             datasets, errors = self.document.reloadLinkedDatasets(
                 self.filenames)
         except EnvironmentError as e:
-            lines.append(_("Error reading file: %s") % cstr(e))
+            lines.append(_("Error reading file: %s") % str(e))
 
         # header showing count
         if len(datasets) > 0:
