@@ -24,11 +24,9 @@ import traceback
 import io
 import numpy as N
 
-from .. import qtall as qt4
-from .. import setting
+from .. import qtall as qt
 from .. import utils
 
-from ..compat import cexec, cstrerror, cbytes, cexceptionuser
 from .commandinterface import CommandInterface
 from . import datasets
 
@@ -37,7 +35,7 @@ h5py = None
 
 def _(text, disambiguation=None, context='DocumentLoader'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class LoadError(RuntimeError):
     """Error when loading document."""
@@ -48,7 +46,7 @@ class LoadError(RuntimeError):
 def bconv(s):
     """Sometimes h5py returns non-unicode strings,
     so hack to decode strings if in wrong format."""
-    if isinstance(s, cbytes):
+    if isinstance(s, bytes):
         return s.decode('utf-8')
     return s
 
@@ -59,7 +57,7 @@ def _importcaller(interface, name, callbackimporterror):
             try:
                 getattr(interface, name)(*args, **argsk)
             except IOError as e:
-                errmsg = cexceptionuser(e)
+                errmsg = str(e)
                 fnameidx = interface.import_filenamearg[name]
                 assert fnameidx >= 0
                 filename = args[fnameidx]
@@ -102,21 +100,21 @@ def executeScript(thedoc, filename, script,
     def genexception(exc):
         info = sys.exc_info()
         backtrace = ''.join(traceback.format_exception(*info))
-        return LoadError(cexceptionuser(exc), backtrace=backtrace)
+        return LoadError(str(exc), backtrace=backtrace)
 
     # compile script and check for security (if reqd)
-    unsafe = [setting.transient_settings['unsafe_mode']]
     while True:
         try:
             compiled = utils.compileChecked(
                 script, mode='exec', filename=filename,
-                ignoresecurity=unsafe[0])
+                ignoresecurity=thedoc.evaluate.inSecureMode(),
+            )
             break
         except utils.SafeEvalException:
             if callbackunsafe is None or not callbackunsafe():
                 raise LoadError(_("Unsafe command in script"))
             # repeat with unsafe mode switched on
-            unsafe[0] = True
+            thedoc.evaluate.setSecurity(True)
         except Exception as e:
             raise genexception(e)
 
@@ -133,10 +131,10 @@ def executeScript(thedoc, filename, script,
     # wrap unsafe calls with a function to check whether ok
     def _unsafecaller(func):
         def wrapped(*args, **argsk):
-            if not unsafe[0]:
+            if not thedoc.evaluate.inSecureMode():
                 if callbackunsafe is None or not callbackunsafe():
                     raise LoadError(_("Unsafe command in script"))
-                unsafe[0] = True
+                thedoc.evaluate.setSecurity(True)
             func(*args, **argsk)
         return wrapped
     for name in interface.unsafe_commands:
@@ -154,7 +152,7 @@ def executeScript(thedoc, filename, script,
     with thedoc.suspend():
         try:
             # actually run script text
-            cexec(compiled, env)
+            exec(compiled, env)
         except LoadError:
             raise
         except Exception as e:
@@ -228,6 +226,8 @@ def loadHDF5Doc(thedoc, filename,
     with thedoc.suspend():
         thedoc.wipe()
         thedoc.filename = filename
+        thedoc.evaluate.updateSecurityFromPath()
+
         hdffile = h5py.File(filename, 'r')
 
         try:
@@ -241,10 +241,11 @@ def loadHDF5Doc(thedoc, filename,
         maxformat = 1
         if vszformat > maxformat:
             raise LoadError(
-                _("This document version (%i) is not supported. "
-                  "It was written by Veusz %s.\n"
-                  "This Veusz only supports document version %i.") %
-                (vszformat, vszversion, maxformat))
+                _(
+                    "This document version (%i) is not supported. "
+                    "It was written by Veusz %s.\n"
+                    "This Veusz only supports document version %i."
+                ) % (vszformat, vszversion, maxformat))
 
         # load document
         script = hdffile['Veusz']['Document']['document'][0].decode('utf-8')
@@ -270,17 +271,20 @@ def loadDocument(thedoc, filename, mode='vsz',
 
     if mode == 'vsz':
         try:
-            with io.open(filename, 'rU', encoding='utf-8') as f:
+            with io.open(filename, 'r', encoding='utf-8') as f:
                 script = f.read()
         except EnvironmentError as e:
-            raise LoadError( _("Cannot open document '%s'\n\n%s") %
-                             (os.path.basename(filename), cstrerror(e)) )
+            raise LoadError(
+                _("Cannot open document '%s'\n\n%s") %
+                (os.path.basename(filename), e.strerror) )
         except UnicodeDecodeError:
-            raise LoadError( _("File '%s' is not a valid Veusz document") %
-                             os.path.basename(filename) )
+            raise LoadError(
+                _("File '%s' is not a valid Veusz document") %
+                os.path.basename(filename) )
 
         thedoc.wipe()
         thedoc.filename = filename
+        thedoc.evaluate.updateSecurityFromPath()
         executeScript(
             thedoc, filename, script,
             callbackunsafe=callbackunsafe,
