@@ -16,10 +16,10 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 from itertools import count
+import base64
 
-from ..compat import czip, CStringIO
+from io import StringIO
 from .. import qtall as qt
 
 from . import doc
@@ -32,6 +32,9 @@ widgetmime = 'text/x-vnd.veusz-widget-3'
 # dataset mime
 datamime = 'text/x-vnd.veusz-data-1'
 
+# svg mime (convertable to `svgfile` widget)
+svgmime = 'image/svg+xml'
+
 def generateWidgetsMime(widgets):
     """Create mime data describing widget and children.
     format is:
@@ -80,7 +83,7 @@ def generateDatasetsMime(datasets, document):
     text = ('\n'.join(output)).encode('utf-8')
     mimedata.setData('text/plain', qt.QByteArray(text))
 
-    textfile = CStringIO()
+    textfile = StringIO()
     for name in datasets:
         # get unlinked copy of dataset
         ds = document.data[name].returnCopy()
@@ -110,7 +113,25 @@ def getClipboardWidgetMime():
 
     If mimedata is set, use this rather than clipboard directly
     """
-    return getWidgetMime(qt.QApplication.clipboard().mimeData())
+    clipboard = qt.QApplication.clipboard()
+    mimedata = clipboard.mimeData()
+    formats = mimedata.formats()
+    widgetmime = getWidgetMime(mimedata)
+    if widgetmime is not None:
+        return widgetmime
+    elif svgmime in formats:
+        ba = mimedata.data(svgmime).data()
+        return convertImgtoWidgetMime(ba, svgmime)
+    else:
+        qimage = clipboard.image()
+        if qimage.isNull():
+            return None
+        else:
+            ba = qt.QByteArray()
+            buffer = qt.QBuffer(ba)
+            buffer.open(qt.QIODevice.WriteOnly)
+            qimage.save(buffer, 'png')
+            return convertImgtoWidgetMime(ba, 'image/png')
 
 def getMimeWidgetTypes(data):
     """Get list of widget types in the mime data."""
@@ -156,6 +177,28 @@ def getMimeWidgetCount(mimedata):
     """Get number of widgets in mimedata."""
     return int( mimedata[:mimedata.find('\n')] )
 
+def convertImgtoWidgetMime(ba, mimetype):
+    """Given image bite array and mimetype, return decoded python string."""
+    if mimetype == svgmime:
+        typename = 'svgfile'
+        name = 'svgfile1'
+        path = '/page1/svgfile1'
+        key = 'embeddedSVGData'
+    else:
+        typename = 'imagefile'
+        name = 'imagefile1'
+        path = '/page1/imagefile1'
+        key = 'embeddedImageData'
+
+    encoded = base64.b64encode(ba).decode('ascii')
+    settings = {'filename': "'{embedded}'",
+                key: "'{}'".format(encoded),
+                }
+    head = ['1', typename, "'{}'".format(name), "'{}'".format(path), '2']
+    body = ["Set('{}', {})".format(s,v) for (s,v) in settings.items()]
+
+    return '\n'.join(head) + '\n' + '\n'.join(body) + '\n'
+
 class OperationWidgetPaste(operations.OperationMultiple):
     """Paste a widget from mime data."""
 
@@ -202,7 +245,7 @@ class OperationWidgetPaste(operations.OperationMultiple):
         newwidgets = []
         widgetline = 1+4*numwidgets
         try:
-            for wtype, name, numline in czip(types, names, widgetslines):
+            for wtype, name, numline in zip(types, names, widgetslines):
                 thisparent = doc.getSuitableParent(wtype, parentwidget)
 
                 if thisparent is None:
@@ -272,7 +315,7 @@ class OperationDataPaste(operations.Operation):
         tempdoc = doc.Document()
         # interpreter to create datasets
         interpreter = commandinterpreter.CommandInterpreter(tempdoc)
-        interpreter.runFile(CStringIO(self.data))
+        interpreter.runFile(StringIO(self.data))
 
         # list of pasted datasets
         self.newds = []
