@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright (C) 2011 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -19,13 +18,12 @@
 
 """A widget for navigating datasets."""
 
-from __future__ import division
 import os.path
-import numpy as N
 import textwrap
 
-from ..compat import crange, citems, czip, cbasestr, cstr
-from .. import qtall as qt4
+import numpy as N
+
+from .. import qtall as qt
 from .. import setting
 from .. import document
 from .. import utils
@@ -35,7 +33,7 @@ from ..utils.treemodel import TMNode, TreeModel
 
 def _(text, disambiguation=None, context="DatasetBrowser"):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 def datasetLinkFile(ds):
     """Get a linked filename from a dataset."""
@@ -77,10 +75,10 @@ class DatasetNode(TMNode):
         if ds.dimensions != 1 or ds.datatype != "numeric":
             return None
 
-        pixmap = qt4.QPixmap(*size)
-        pixmap.fill(qt4.Qt.transparent)
-        p = qt4.QPainter(pixmap)
-        p.setRenderHint(qt4.QPainter.Antialiasing)
+        pixmap = qt.QPixmap(*size)
+        pixmap.fill(qt.Qt.transparent)
+        p = qt.QPainter(pixmap)
+        p.setRenderHint(qt.QPainter.Antialiasing)
 
         # calculate data points
         try:
@@ -98,19 +96,19 @@ class DatasetNode(TMNode):
             x, y = x[finite], y[finite]
             x = x * (1./len(x)) * size[0]
 
-            poly = qt4.QPolygonF()
+            poly = qt.QPolygonF()
             utils.addNumpyToPolygonF(poly, x, size[1]-y)
-            p.setPen( qt4.QPen(qt4.Qt.blue) )
+            p.setPen( qt.QPen(qt.Qt.blue) )
             p.drawPolyline(poly)
 
             # draw x axis if span 0
-            p.setPen( qt4.QPen(qt4.Qt.black) )
+            p.setPen( qt.QPen(qt.Qt.black) )
             if minval <= 0 and maxval > 0:
                 y0 = size[1] - (0-minval)/(maxval-minval)*size[1]
-                p.drawLine(x[0], y0, x[-1], y0)
+                p.drawLine(qt.QLineF(x[0], y0, x[-1], y0))
             else:
-                p.drawLine(x[0], size[1], x[-1], size[1])
-            p.drawLine(x[0], 0, x[0], size[1])
+                p.drawLine(qt.QLineF(x[0], size[1], x[-1], size[1]))
+            p.drawLine(qt.QLineF(x[0], 0, x[0], size[1]))
 
         except (ValueError, ZeroDivisionError):
             # zero sized array after filtering or min == max, so return None
@@ -228,10 +226,10 @@ class DatasetRelationModel(TreeModel):
         if self.filter != "":
             keep = False
             if any([t.find(self.filter) >= 0 for t in ds.tags
-                    if isinstance(t, cbasestr)]):
+                    if isinstance(t, str)]):
                 keep = True
             if any([t.find(self.filter) >= 0 for t in node.data
-                    if isinstance(t, cbasestr)]):
+                    if isinstance(t, str)]):
                 keep = True
         # check dimensions haven't been filtered
         if ( self.filterdims is not None and
@@ -257,7 +255,7 @@ class DatasetRelationModel(TreeModel):
             cols += [_('check')]
 
         tree = TMNode(heads , None)
-        for name, ds in citems(self.doc.data):
+        for name, ds in self.doc.data.items():
             child = DatasetNode(self, name, cols, None)
 
             # add if not filtered for filtering
@@ -278,7 +276,7 @@ class DatasetRelationModel(TreeModel):
             colitems = colitems + [_('check')]
 
         grpnodes = {}
-        for name, ds in citems(self.doc.data):
+        for name, ds in self.doc.data.items():
             child = DatasetNode(self, name, colitems, None)
 
             # check whether filtered out
@@ -300,7 +298,7 @@ class DatasetRelationModel(TreeModel):
             ["name", "size", "type"],
             lambda ds: (datasetLinkFile(ds),),
             FilenameNode
-            )
+        )
 
     def makeGrpTreeSize(self):
         """Make a tree of datasets grouped by dataset size."""
@@ -309,7 +307,7 @@ class DatasetRelationModel(TreeModel):
             ["name", "type", "linkfile"],
             lambda ds: (ds.userSize(),),
             TMNode
-            )
+        )
 
     def makeGrpTreeType(self):
         """Make a tree of datasets grouped by dataset type."""
@@ -318,7 +316,7 @@ class DatasetRelationModel(TreeModel):
             ["name", "size", "linkfile"],
             lambda ds: (ds.dstype,),
             TMNode
-            )
+        )
 
     def makeGrpTreeTags(self):
         """Make a tree of datasets grouped by tags."""
@@ -334,7 +332,7 @@ class DatasetRelationModel(TreeModel):
             ["name", "size", "type", "linkfile"],
             getgrp,
             TMNode
-            )
+        )
 
     def flags(self, idx):
         """Return model flags for index."""
@@ -345,10 +343,10 @@ class DatasetRelationModel(TreeModel):
             col = idx.column()
             if not self.readonly and col == 0:
                 # renameable dataset
-                f |= qt4.Qt.ItemIsEditable
+                f |= qt.Qt.ItemIsEditable
             elif obj.cols[col] == "check":
                 # checkable dataset
-                f |= qt4.Qt.ItemIsUserCheckable
+                f |= qt.Qt.ItemIsUserCheckable
         return f
 
     def setData(self, idx, val, role):
@@ -377,7 +375,7 @@ class DatasetRelationModel(TreeModel):
             self.refresh()
             return True
 
-    @qt4.pyqtSlot()
+    @qt.pyqtSlot()
     def refresh(self):
         """Update tree of datasets when document changes."""
 
@@ -387,15 +385,15 @@ class DatasetRelationModel(TreeModel):
             "size": self.makeGrpTreeSize,
             "type": self.makeGrpTreeType,
             "tags": self.makeGrpTreeTags,
-            }[self.grouping]()
+        }[self.grouping]()
 
         self.syncTree(tree)
 
-class DatasetsNavigatorTree(qt4.QTreeView):
+class DatasetsNavigatorTree(qt.QTreeView):
     """Tree view for dataset names."""
 
-    updateitem = qt4.pyqtSignal()
-    selecteddatasets = qt4.pyqtSignal(list)
+    updateitem = qt.pyqtSignal()
+    selecteddatasets = qt.pyqtSignal(list)
 
     def __init__(self, doc, mainwin, grouping, parent,
                  readonly=False, filterdims=None, filterdtype=None,
@@ -410,7 +408,7 @@ class DatasetsNavigatorTree(qt4.QTreeView):
         checkable: allow datasets to be selected
         """
 
-        qt4.QTreeView.__init__(self, parent)
+        qt.QTreeView.__init__(self, parent)
         self.doc = doc
         self.mainwindow = mainwin
         self.model = DatasetRelationModel(
@@ -420,10 +418,10 @@ class DatasetsNavigatorTree(qt4.QTreeView):
             checkable=checkable)
 
         self.setModel(self.model)
-        self.setSelectionMode(qt4.QTreeView.ExtendedSelection)
-        self.setSelectionBehavior(qt4.QTreeView.SelectRows)
+        self.setSelectionMode(qt.QTreeView.ExtendedSelection)
+        self.setSelectionBehavior(qt.QTreeView.SelectRows)
         self.setUniformRowHeights(True)
-        self.setContextMenuPolicy(qt4.Qt.CustomContextMenu)
+        self.setContextMenuPolicy(qt.Qt.CustomContextMenu)
         if not readonly:
             self.customContextMenuRequested.connect(self.showContextMenu)
         self.model.refresh()
@@ -432,9 +430,9 @@ class DatasetsNavigatorTree(qt4.QTreeView):
         # stretch of columns
         hdr = self.header()
         hdr.setStretchLastSection(False)
-        hdr.setSectionResizeMode(0, qt4.QHeaderView.Stretch)
-        for col in crange(1, 3):
-            hdr.setSectionResizeMode(col, qt4.QHeaderView.ResizeToContents)
+        hdr.setSectionResizeMode(0, qt.QHeaderView.Stretch)
+        for col in range(1, 3):
+            hdr.setSectionResizeMode(col, qt.QHeaderView.ResizeToContents)
 
         # when documents have finished opening, expand all nodes
         if mainwin is not None:
@@ -462,16 +460,16 @@ class DatasetsNavigatorTree(qt4.QTreeView):
         """Find, and if possible select dataset name."""
 
         matches = self.model.match(
-            self.model.index(0, 0, qt4.QModelIndex()),
-            qt4.Qt.DisplayRole, dsname, -1,
-            qt4.Qt.MatchFixedString | qt4.Qt.MatchCaseSensitive |
-            qt4.Qt.MatchRecursive )
+            self.model.index(0, 0, qt.QModelIndex()),
+            qt.Qt.DisplayRole, dsname, -1,
+            qt.Qt.MatchFixedString | qt.Qt.MatchCaseSensitive |
+            qt.Qt.MatchRecursive )
         for idx in matches:
             if isinstance(self.model.objFromIndex(idx), DatasetNode):
                 self.selectionModel().setCurrentIndex(
-                    idx, qt4.QItemSelectionModel.SelectCurrent |
-                    qt4.QItemSelectionModel.Clear |
-                    qt4.QItemSelectionModel.Rows )
+                    idx, qt.QItemSelectionModel.SelectCurrent |
+                    qt.QItemSelectionModel.Clear |
+                    qt.QItemSelectionModel.Rows )
 
     def showContextMenu(self, pt):
         """Context menu for nodes."""
@@ -484,7 +482,7 @@ class DatasetsNavigatorTree(qt4.QTreeView):
         # unique list of types of nodes
         types = set([ type(n) for n in nodes ])
 
-        menu = qt4.QMenu()
+        menu = qt.QMenu()
         # put contexts onto submenus if multiple types selected
         if DatasetNode in types:
             thismenu = menu
@@ -504,7 +502,7 @@ class DatasetsNavigatorTree(qt4.QTreeView):
         def _paste():
             """Paste dataset(s)."""
             if document.isClipboardDataMime():
-                mime = qt4.QApplication.clipboard().mimeData()
+                mime = qt.QApplication.clipboard().mimeData()
                 self.doc.applyOperation(document.OperationDataPaste(mime))
 
         # if there is data to paste, add menu item
@@ -523,13 +521,13 @@ class DatasetsNavigatorTree(qt4.QTreeView):
 
         def _edit():
             """Open up dialog box to recreate dataset."""
-            for dataset, dsname in czip(datasets, dsnames):
+            for dataset, dsname in zip(datasets, dsnames):
                 if type(dataset) in dataeditdialog.recreate_register:
                     dataeditdialog.recreate_register[type(dataset)](
                         self.mainwindow, self.doc, dataset, dsname)
         def _edit_data():
             """Open up data edit dialog."""
-            for dataset, dsname in czip(datasets, dsnames):
+            for dataset, dsname in zip(datasets, dsnames):
                 if type(dataset) not in dataeditdialog.recreate_register:
                     self.mainwindow.slotDataEdit(editdataset=dsname)
         def _delete():
@@ -543,7 +541,7 @@ class DatasetsNavigatorTree(qt4.QTreeView):
             self.doc.applyOperation(
                 document.OperationMultiple(
                     [document.OperationDatasetUnlinkFile(n)
-                     for d,n in czip(datasets,dsnames)
+                     for d,n in zip(datasets,dsnames)
                      if d.canUnlink() and d.linked],
                     descr=_('unlink dataset(s)')))
         def _unlink_relation():
@@ -551,13 +549,13 @@ class DatasetsNavigatorTree(qt4.QTreeView):
             self.doc.applyOperation(
                 document.OperationMultiple(
                     [document.OperationDatasetUnlinkRelation(n)
-                     for d,n in czip(datasets,dsnames)
+                     for d,n in zip(datasets,dsnames)
                      if d.canUnlink() and not d.linked],
                     descr=_('unlink dataset(s)')))
         def _copy():
             """Copy data to clipboard."""
             mime = document.generateDatasetsMime(dsnames, self.doc)
-            qt4.QApplication.clipboard().setMimeData(mime)
+            qt.QApplication.clipboard().setMimeData(mime)
 
         # editing
         recreate = [type(d) in dataeditdialog.recreate_register
@@ -595,13 +593,13 @@ class DatasetsNavigatorTree(qt4.QTreeView):
             a.setChecked( all(state) )
 
         def addtag():
-            tag, ok = qt4.QInputDialog.getText(
+            tag, ok = qt.QInputDialog.getText(
                 self, _("New tag"), _("Enter new tag"))
             if ok:
                 tag = tag.strip().replace(' ', '')
                 if tag:
                     self.doc.applyOperation( document.OperationDataTag(
-                            tag, dsnames) )
+                        tag, dsnames) )
         tagmenu.addAction(_("Add..."), addtag)
 
         # copy
@@ -660,14 +658,14 @@ class DatasetsNavigatorTree(qt4.QTreeView):
 
     def keyPressEvent(self, event):
         """Enter key selects widget."""
-        if event.key() in (qt4.Qt.Key_Return, qt4.Qt.Key_Enter):
+        if event.key() in (qt.Qt.Key_Return, qt.Qt.Key_Enter):
             self.updateitem.emit()
             return
-        qt4.QTreeView.keyPressEvent(self, event)
+        qt.QTreeView.keyPressEvent(self, event)
 
     def mouseDoubleClickEvent(self, event):
         """Emit updateitem signal if double clicked."""
-        retn = qt4.QTreeView.mouseDoubleClickEvent(self, event)
+        retn = qt.QTreeView.mouseDoubleClickEvent(self, event)
         self.updateitem.emit()
         return retn
 
@@ -707,7 +705,7 @@ class DatasetsNavigatorTree(qt4.QTreeView):
         self.model.checked_datasets.clear()
         self.model.refresh()
 
-class DatasetBrowser(qt4.QWidget):
+class DatasetBrowser(qt.QWidget):
     """Widget which shows the document's datasets."""
 
     # how datasets can be grouped
@@ -715,10 +713,10 @@ class DatasetBrowser(qt4.QWidget):
     grpentries = {
         "none": _("None"),
         "filename": _("Filename"),
-        "type": _("Type"), 
+        "type": _("Type"),
         "size": _("Size"),
         "tags": _("Tags"),
-        }
+    }
 
     def __init__(self, thedocument, mainwin, parent, readonly=False,
                  filterdims=None, filterdtype=None, checkable=False):
@@ -732,18 +730,18 @@ class DatasetBrowser(qt4.QWidget):
         checkable: allow datasets to be selected
         """
 
-        qt4.QWidget.__init__(self, parent)
-        self.layout = qt4.QVBoxLayout()
+        qt.QWidget.__init__(self, parent)
+        self.layout = qt.QVBoxLayout()
         self.setLayout(self.layout)
 
         # options for navigator are in this layout
-        self.optslayout = qt4.QHBoxLayout()
+        self.optslayout = qt.QHBoxLayout()
 
         # grouping options - use a menu to choose the grouping
-        self.grpbutton = qt4.QPushButton(_("Group"))
-        self.grpmenu = qt4.QMenu()
+        self.grpbutton = qt.QPushButton(_("Group"))
+        self.grpmenu = qt.QMenu()
         self.grouping = setting.settingdb.get("navtree_grouping", "filename")
-        self.grpact = qt4.QActionGroup(self)
+        self.grpact = qt.QActionGroup(self)
         self.grpact.setExclusive(True)
         for name in self.grpnames:
             a = self.grpmenu.addAction(self.grpentries[name])
@@ -758,7 +756,7 @@ class DatasetBrowser(qt4.QWidget):
         self.optslayout.addWidget(self.grpbutton)
 
         # filtering by entering text
-        searchlabel = qt4.QLabel()
+        searchlabel = qt.QLabel()
         searchlabel.setPixmap(utils.getIcon('kde-search-jss').pixmap(18,18))
         self.optslayout.addWidget(searchlabel)
         self.filteredit = LineEditWithClear()
@@ -806,8 +804,8 @@ class DatasetBrowserPopup(DatasetBrowser):
     This is used by setting.controls.Dataset
     """
 
-    closing = qt4.pyqtSignal()
-    newdataset = qt4.pyqtSignal(cstr)
+    closing = qt.pyqtSignal()
+    newdataset = qt.pyqtSignal(str)
 
     def __init__(self, document, dsname, parent,
                  filterdims=None, filterdtype=None):
@@ -821,8 +819,8 @@ class DatasetBrowserPopup(DatasetBrowser):
         DatasetBrowser.__init__(
             self, document, None, parent, readonly=True,
             filterdims=filterdims, filterdtype=filterdtype)
-        self.setWindowFlags(qt4.Qt.Popup)
-        self.setAttribute(qt4.Qt.WA_DeleteOnClose)
+        self.setWindowFlags(qt.Qt.Popup)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
         self.spacing = self.fontMetrics().height()
 
         utils.positionFloatingPopup(self, parent)
@@ -835,9 +833,9 @@ class DatasetBrowserPopup(DatasetBrowser):
 
     def eventFilter(self, node, event):
         """Grab clicks outside this window to close it."""
-        if ( isinstance(event, qt4.QMouseEvent) and
-             event.buttons() != qt4.Qt.NoButton ):
-            frame = qt4.QRect(0, 0, self.width(), self.height())
+        if ( isinstance(event, qt.QMouseEvent) and
+             event.buttons() != qt.Qt.NoButton ):
+            frame = qt.QRect(0, 0, self.width(), self.height())
             if not frame.contains(event.pos()):
                 self.close()
                 return True
@@ -845,7 +843,7 @@ class DatasetBrowserPopup(DatasetBrowser):
 
     def sizeHint(self):
         """A reasonable size for the text editor."""
-        return qt4.QSize(self.spacing*30, self.spacing*20)
+        return qt.QSize(self.spacing*30, self.spacing*20)
 
     def closeEvent(self, event):
         """Tell the calling widget that we are closing."""
