@@ -20,7 +20,6 @@
 Numerical fitting of functions to data.
 """
 
-from __future__ import division, print_function
 import sys
 
 import numpy as N
@@ -29,8 +28,6 @@ try:
 except:
     import scipy.linalg as NLA
 
-from ..compat import crange
-
 def fitLM(func, params, xvals, yvals, errors,
           stopdeltalambda = 1e-5,
           deltaderiv = 1e-5, maxiters = 20, Lambda = 1e-4):
@@ -76,7 +73,7 @@ def fitLM(func, params, xvals, yvals, errors,
         # also calculate the derivative of the function at each of the points
         # wrt the parameters
 
-        for i in crange( len(params) ):
+        for i in range( len(params) ):
             params[i] += deltaderiv
             new_func = func(params, xvals)
             chi2_new = ((new_func - yvals)**2 * inve2).sum()
@@ -91,8 +88,8 @@ def fitLM(func, params, xvals, yvals, errors,
 
         # calculate alpha matrix
         # FIXME: stupid - must be a better way to avoid this iteration
-        for j in crange( len(params) ):
-            for k in crange(j+1):
+        for j in range( len(params) ):
+            for k in range(j+1):
                 v = (derivs[j]*derivs[k] * inve2).sum()
                 alpha[j][k] = v
                 alpha[k][j] = v
@@ -141,4 +138,3 @@ def fitLM(func, params, xvals, yvals, errors,
     print("chi^2 = %g, dof = %i, reduced-chi^2 = %g" % (chi2, dof, redchi2))
 
     return (params, chi2, dof)
-
