@@ -18,12 +18,10 @@
 
 '''An axis which can be broken in places.'''
 
-from __future__ import division
 import bisect
 
 import numpy as N
 
-from ..compat import crange, czip
 from .. import qtall as qt
 from .. import setting
 from .. import document
@@ -54,18 +52,16 @@ class AxisBroken(axis.Axis):
         axis.Axis.addSettings(s)
 
         s.add( setting.FloatList(
-                'breakPoints',
-                [],
-                descr = _('Pairs of values to start and stop breaks'),
-                usertext = _('Break pairs'),
-                ), 4 )
+            'breakPoints',
+            [],
+            descr = _('Pairs of values to start and stop breaks'),
+            usertext = _('Break pairs')), 4 )
         s.add( setting.FloatList(
-                'breakPosns',
-                [],
-                descr = _('Positions (fractions) along axis where to break'),
-                usertext = _('Break positions'),
-                formatting=True,
-                ) )
+            'breakPosns',
+            [],
+            descr = _('Positions (fractions) along axis where to break'),
+            usertext = _('Break positions'),
+            formatting=True) )
 
     def switchBreak(self, num, posn, otherposition=None):
         """Switch to break given (or None to disable)."""
@@ -104,7 +100,7 @@ class AxisBroken(axis.Axis):
 
         # first work out which break region the values are in
         out = []
-        for sval, val in czip(svals, vals):
+        for sval, val in zip(svals, vals):
             # find index for appropriated scaled starting value
             breaki = bisect.bisect_left(self.posstarts, sval) - 1
 
@@ -131,6 +127,14 @@ class AxisBroken(axis.Axis):
         if self.rangeswitch is not None:
             return axis.Axis._graphToPlotter(self, vals)
 
+        # support single int/float values
+        try:
+            iter(vals)
+            issingle = False
+        except TypeError:
+            vals = N.array([vals])
+            issingle = True
+
         out = []
         for val in vals:
             breaki = bisect.bisect_left(self.breakvstarts, val) - 1
@@ -148,12 +152,16 @@ class AxisBroken(axis.Axis):
                 else:
                     # lookup value
                     self.switchBreak(breaki, self.currentbounds)
-                    coord = axis.Axis._graphToPlotter(self, N.array([val]))
+                    coord = axis.Axis._graphToPlotter(self, N.array([val]))[0]
             else:
                 coord = N.nan
             out.append(coord)
         self.switchBreak(None, self.currentbounds)
-        return N.array(out)
+
+        if issingle:
+            return out[0]
+        else:
+            return N.array(out)
 
     def updateAxisLocation(self, bounds, otherposition=None):
         """Recalculate broken axis positions."""
@@ -219,7 +227,7 @@ class AxisBroken(axis.Axis):
 
         # filter to range
         newpoints = []
-        for i in crange(0, len(points)//2 * 2, 2):
+        for i in range(0, len(points)//2 * 2, 2):
             if points[i] >= min(r) and points[i+1] <= max(r):
                 newpoints += [points[i], points[i+1]]
 
@@ -228,13 +236,13 @@ class AxisBroken(axis.Axis):
             self.plottedrange[1]]
 
         # axis values for starting and stopping
-        self.breakvstarts = [ self.breakvlist[i*2] for i in crange(num) ]
-        self.breakvstops = [ self.breakvlist[i*2+1] for i in crange(num) ]
+        self.breakvstarts = [ self.breakvlist[i*2] for i in range(num) ]
+        self.breakvstops = [ self.breakvlist[i*2+1] for i in range(num) ]
 
         # compute ticks for each range
         self.minorticklist = []
         self.majorticklist = []
-        for i in crange(self.breakvnum):
+        for i in range(self.breakvnum):
             self.plottedrange = [self.breakvstarts[i], self.breakvstops[i]]
             reverse = self.plottedrange[0] > self.plottedrange[1]
             if reverse:
@@ -263,7 +271,7 @@ class AxisBroken(axis.Axis):
         if not s.Line.hide:
             self._drawAxisLine(painter, posn)
 
-        for i in crange(self.breakvnum):
+        for i in range(self.breakvnum):
             self.switchBreak(i, posn, otherposition=otheredge)
 
             # plot coordinates of ticks
@@ -292,7 +300,7 @@ class AxisBroken(axis.Axis):
             markdirn = -markdirn
 
         # add shape for each break
-        for start, stop in czip( self.posstarts[1:], self.posstops[:-1] ):
+        for start, stop in zip( self.posstarts[1:], self.posstops[:-1] ):
             p1 += [stop, (start+stop)*0.5, start]
             p2 += [0, markdirn*(start-stop)*0.5, 0]
 
@@ -346,19 +354,21 @@ class AxisBroken(axis.Axis):
         with painter:
             painter.save()
             painter.setClipRect( qt.QRectF(
-                    qt.QPointF(parentposn[0], parentposn[1]),
-                    qt.QPointF(parentposn[2], parentposn[3]) ) )
+                qt.QPointF(parentposn[0], parentposn[1]),
+                qt.QPointF(parentposn[2], parentposn[3]) ) )
 
-            for i in crange(self.breakvnum):
+            for i in range(self.breakvnum):
                 self.switchBreak(i, parentposn)
                 if not s.MinorGridLines.hide:
                     coordminorticks = self._graphToPlotter(self.minorticklist[i])
-                    self._drawGridLines('MinorGridLines', painter, coordminorticks,
-                                        parentposn)
+                    self._drawGridLines(
+                        'MinorGridLines', painter, coordminorticks,
+                        parentposn)
                 if not s.GridLines.hide:
                     coordticks = self._graphToPlotter(self.majorticklist[i])
-                    self._drawGridLines('GridLines', painter, coordticks,
-                                        parentposn)
+                    self._drawGridLines(
+                        'GridLines', painter, coordticks,
+                        parentposn)
 
             self.switchBreak(None, parentposn)
             painter.restore()
@@ -385,7 +395,7 @@ class AxisBroken(axis.Axis):
 
         max_delta = 0
         suppresstext = False
-        for i in crange(self.breakvnum):
+        for i in range(self.breakvnum):
             self.switchBreak(i, posn)
 
             if self.plottedrange[0]==self.plottedrange[1]:
@@ -408,9 +418,10 @@ class AxisBroken(axis.Axis):
             # plot tick labels
             suppresstext = self._suppressText(painter, parentposn, outerbounds)
             if not s.TickLabels.hide and not suppresstext:
-                self._drawTickLabels(phelper, painter, coordticks, sign,
-                                     outerbounds, self.majorticklist[i],
-                                     texttorender)
+                self._drawTickLabels(
+                    phelper, painter, coordticks, sign,
+                    outerbounds, self.majorticklist[i],
+                    texttorender)
 
             # this is the maximum delta of any of the breaks
             max_delta = max(max_delta, self._delta_axis)
@@ -426,8 +437,8 @@ class AxisBroken(axis.Axis):
 
         # make control item for axis
         phelper.setControlGraph(self, [ controlgraph.ControlAxisLine(
-                    self, phelper, self.settings.direction, self.coordParr1,
-                    self.coordParr2, self.coordPerp, posn) ])
+            self, phelper, self.settings.direction, self.coordParr1,
+            self.coordParr2, self.coordPerp, posn) ])
 
 # allow the factory to instantiate the widget
-document.thefactory.register( AxisBroken )
+document.thefactory.register(AxisBroken)
