@@ -22,11 +22,9 @@ Contour plotting requires that the veusz_helpers package is installed,
 as a C routine (taken from matplotlib) is used to trace the contours.
 """
 
-from __future__ import division, print_function
 import sys
 import math
 
-from ..compat import czip, crange
 from .. import qtall as qt
 import numpy as N
 
@@ -36,12 +34,8 @@ from .. import utils
 
 from . import plotters
 
-try:
-    from ..helpers._nc_cntr import Cntr
-    from ..helpers.qtloops import LineLabeller
-except ImportError:
-    Cntr = None
-    LineLabeller = object   # allow class definition below
+from ..helpers._nc_cntr import Cntr
+from ..helpers.qtloops import LineLabeller
 
 def _(text, disambiguation=None, context='Contour'):
     """Translate text."""
@@ -95,14 +89,14 @@ class ContourFills(setting.Settings):
         setting.Settings.__init__(self, name, **args)
         self.add( setting.FillSet(
             'fills', [],
-            descr = _('Fill styles to plot between contours'),
+            descr=_('Fill styles to plot between contours'),
             usertext=_('Fill styles'),
             formatting=True) )
         self.add( setting.Bool(
             'hide', False,
-            descr = _('Hide fills'),
-            usertext = _('Hide'),
-            formatting = True) )
+            descr=_('Hide fills'),
+            usertext=_('Hide'),
+            formatting=True) )
 
 class ContourLines(setting.Settings):
     """Settings for contour lines."""
@@ -111,14 +105,14 @@ class ContourLines(setting.Settings):
         self.add( setting.LineSet(
             'lines',
             [('solid', '1pt', 'black', False)],
-            descr = _('Line styles to plot the contours '
-                      'using'), usertext=_('Line styles'),
+            descr=_('Line styles to plot the contours using'),
+            usertext=_('Line styles'),
             formatting=True) )
         self.add( setting.Bool(
             'hide', False,
-            descr = _('Hide lines'),
-            usertext = _('Hide'),
-            formatting = True) )
+            descr=_('Hide lines'),
+            usertext=_('Hide'),
+            formatting=True) )
 
 class SubContourLines(setting.Settings):
     """Sub-dividing contour line settings."""
@@ -127,14 +121,13 @@ class SubContourLines(setting.Settings):
         self.add( setting.LineSet(
             'lines',
             [('dot1', '1pt', 'black', False)],
-            descr = _('Line styles used for sub-contours'),
+            descr=_('Line styles used for sub-contours'),
             usertext=_('Line styles'),
             formatting=True) )
         self.add( setting.Int(
             'numLevels', 5,
             minval=2,
-            descr=_('Number of sub-levels to plot between '
-                    'each contour'),
+            descr=_('Number of sub-levels to plot between each contour'),
             usertext='Levels') )
         self.add( setting.Bool(
             'hide', True,
@@ -149,12 +142,12 @@ class ContourLabel(setting.Text):
         setting.Text.__init__(self, name, **args)
         self.add( setting.Str(
             'format', '%.3Vg',
-            descr = _('Format of the tick labels'),
+            descr=_('Format of the tick labels'),
             usertext=_('Format')) )
         self.add( setting.Float(
             'scale', 1.,
-            descr=_('A scale factor to apply to the values '
-                    'of the tick labels'),
+            descr=_(
+                'A scale factor to apply to the values of the tick labels'),
             usertext=_('Scale')) )
         self.add( setting.Bool(
             'rotate',
@@ -177,11 +170,6 @@ class Contour(plotters.GenericPlotter):
 
         plotters.GenericPlotter.__init__(self, parent, name=name)
 
-        if Cntr is None:
-            print(('WARNING: Veusz cannot import contour module\n'
-                   'Please run python setup.py build\n'
-                   'Contour support is disabled'), file=sys.stderr)
-
         # keep track of settings so we recalculate when necessary
         self.contsettings = None
 
@@ -197,77 +185,69 @@ class Contour(plotters.GenericPlotter):
 
         s.add( setting.DatasetExtended(
             'data', '',
-            dimensions = 2,
-            descr = _('Dataset to plot'),
-            usertext=_('Dataset')),
-               0 )
+            dimensions=2,
+            descr=_('Dataset to plot'),
+            usertext=_('Dataset')), 0 )
         s.add( setting.FloatOrAuto(
             'min', 'Auto',
-            descr = _('Minimum value of contour scale'),
-            usertext=_('Min. value')),
-               1 )
+            descr=_('Minimum value of contour scale'),
+            usertext=_('Min. value')), 1 )
         s.add( setting.FloatOrAuto(
             'max', 'Auto',
-            descr = _('Maximum value of contour scale'),
-            usertext=_('Max. value')),
-               2 )
+            descr=_('Maximum value of contour scale'),
+            usertext=_('Max. value')), 2 )
         s.add( setting.Int(
             'numLevels', 5,
-            minval = 1,
-            descr = _('Number of contour levels to plot'),
-            usertext=_('Number levels')),
-               3 )
+            minval=1,
+            descr=_('Number of contour levels to plot'),
+            usertext=_('Number levels')), 3 )
         s.add( setting.Choice(
             'scaling',
             ['linear', 'sqrt', 'log', 'squared', 'manual'],
             'linear',
-            descr = _('Scaling between contour levels'),
-            usertext=_('Scaling')),
-               4 )
+            descr=_('Scaling between contour levels'),
+            usertext=_('Scaling')), 4 )
         s.add( setting.FloatList(
             'manualLevels',
             [],
-            descr = _('Levels to use for manual scaling'),
-            usertext=_('Manual levels')),
-               5 )
+            descr=_('Levels to use for manual scaling'),
+            usertext=_('Manual levels')), 5 )
 
         s.add( setting.Bool(
             'keyLevels',
             False,
             descr=_('Show levels in key'),
-            usertext=_('Levels in key')),
-               6 )
+            usertext=_('Levels in key')), 6 )
 
         s.add( setting.FloatList(
             'levelsOut',
             [],
-            descr = _('Levels used in the plot'),
-            usertext=_('Output levels')),
-               7, readonly=True )
+            descr=_('Levels used in the plot'),
+            usertext=_('Output levels')), 7, readonly=True )
 
         s.add( ContourLabel(
             'ContourLabels',
-            descr = _('Contour label settings'),
-            usertext = _('Contour labels')),
-               pixmap = 'settings_axisticklabels' )
+            descr=_('Contour label settings'),
+            usertext=_('Contour labels')),
+            pixmap='settings_axisticklabels' )
 
         s.add( ContourLines(
             'Lines',
             descr=_('Contour lines'),
             usertext=_('Contour lines')),
-               pixmap = 'settings_contourline' )
+            pixmap='settings_contourline' )
 
         s.add( ContourFills(
             'Fills',
             descr=_('Fill within contours'),
             usertext=_('Contour fills')),
-               pixmap = 'settings_contourfill' )
+            pixmap='settings_contourfill' )
 
         s.add( SubContourLines(
             'SubLines',
             descr=_('Sub-contour lines'),
             usertext=_('Sub-contour lines')),
-               pixmap = 'settings_subcontourline' )
+            pixmap='settings_subcontourline' )
 
         s.add( setting.SettingBackwardCompat('lines', 'Lines/lines', None) )
         s.add( setting.SettingBackwardCompat('fills', 'Fills/fills', None) )
@@ -283,7 +263,7 @@ class Contour(plotters.GenericPlotter):
             out.append( s.data )
         if s.scaling == 'manual':
             out.append('manual levels (%s)' %  (
-                    ', '.join([str(i) for i in s.manualLevels])))
+                ', '.join([str(i) for i in s.manualLevels])))
         else:
             out.append('%(numLevels)i %(scaling)s levels (%(min)s to %(max)s)' % s)
         return ', '.join(out)
@@ -383,7 +363,7 @@ class Contour(plotters.GenericPlotter):
         elif scaling == 'manual':
             drange = N.arange(1, num)
             out = [[]]
-            for conmin, conmax in czip(levels[:-1], levels[1:]):
+            for conmin, conmax in zip(levels[:-1], levels[1:]):
                 delta = (conmax-conmin) / num
                 out.append( conmin+drange*delta )
             slev = N.hstack(out)
@@ -439,7 +419,8 @@ class Contour(plotters.GenericPlotter):
         """Draw key for contour level."""
         painter.setPen(
             self.settings.Lines.get('lines').makePen(painter, number))
-        painter.drawLine(x, y+height/2, x+width, y+height/2)
+        painter.drawLine(
+            qt.QPointF(x, y+height/2), qt.QPointF(x+width, y+height/2))
 
     def checkContoursUpToDate(self):
         """Update contours if necessary.
@@ -524,7 +505,7 @@ class Contour(plotters.GenericPlotter):
             # trace the polygons between the contours
             if len(s.Fills.fills) != 0 and len(levels) > 1 and not s.Fills.hide:
                 self._cachedpolygons = []
-                for level1, level2 in czip(levels[:-1], levels[1:]):
+                for level1, level2 in zip(levels[:-1], levels[1:]):
                     linelist = c.trace(level1, level2)
                     self._cachedpolygons.append( finitePoly(linelist) )
 
@@ -593,7 +574,7 @@ class Contour(plotters.GenericPlotter):
         linelabeller.process()
         painter.setClipPath(linelabeller.clippath)
 
-        for i in crange(linelabeller.getNumPolySets()):
+        for i in range(linelabeller.getNumPolySets()):
             polyset = linelabeller.getPolySet(i)
             painter.setPen(linestyles.makePen(painter, levels[i]))
             for poly in polyset:
@@ -604,16 +585,20 @@ class Contour(plotters.GenericPlotter):
     def plotContours(self, painter, posn, axes, clip):
         """Plot the traced contours on the painter."""
         s = self.settings
-        self._plotContours(painter, posn, axes, s.Lines.get('lines'),
-                           self._cachedcontours,
-                           not s.ContourLabels.hide, s.Lines.hide, clip)
+        self._plotContours(
+            painter, posn, axes, s.Lines.get('lines'),
+            self._cachedcontours,
+            not s.ContourLabels.hide, s.Lines.hide, clip
+        )
 
     def plotSubContours(self, painter, posn, axes, clip):
         """Plot sub contours on painter."""
         s = self.settings
-        self._plotContours(painter, posn, axes, s.SubLines.get('lines'),
-                           self._cachedsubcontours,
-                           False, s.SubLines.hide, clip)
+        self._plotContours(
+            painter, posn, axes, s.SubLines.get('lines'),
+            self._cachedsubcontours,
+            False, s.SubLines.hide, clip
+        )
 
     def plotContourFills(self, painter, posn, axes, clip):
         """Plot the traced contours on the painter."""
@@ -646,4 +631,4 @@ class Contour(plotters.GenericPlotter):
             utils.brushExtFillPath(painter, brush, path)
 
 # allow the factory to instantiate a contour
-document.thefactory.register( Contour )
+document.thefactory.register(Contour)
