@@ -18,13 +18,11 @@
 
 """Plotting a line with arrowheads or labels."""
 
-from __future__ import division
 import math
 import itertools
 import numpy as N
 
-from ..compat import czip
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import setting
 from .. import document
 from .. import utils
@@ -34,7 +32,7 @@ from . import plotters
 
 def _(text, disambiguation=None, context='Line'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class Line(plotters.FreePlotter):
     """A line on the plot/graph."""
@@ -58,8 +56,9 @@ class Line(plotters.FreePlotter):
             'mode',
             ('length-angle', 'point-to-point'),
             'length-angle',
-            descr=_('Provide line position and length,angle or '
-                    'first and second points'),
+            descr=_(
+                'Provide line position and length,angle '
+                'or first and second points'),
             usertext=_('Mode'),
             formatting=False,
             showfn=klass.showOrHideSetn), 0)
@@ -73,48 +72,56 @@ class Line(plotters.FreePlotter):
         s.add( setting.DatasetExtended(
             'angle',
             [0.],
-            descr=_('List of angle of lines, dataset or expression '
-                    '(degrees)'),
+            descr=_(
+                'List of angle of lines, dataset or expression (degrees)'),
             usertext=_('Angles'),
             formatting=False), 5 )
         s.add( setting.DatasetExtended(
             'xPos2',
             [1.],
-            descr=_('List of fractional X coordinates, dataset or '
-                    'expression for point 2'),
+            descr=_(
+                'List of fractional X coordinates, dataset or '
+                'expression for point 2'),
             usertext=_('X positions 2'),
             formatting=False), 6 )
         s.add( setting.DatasetExtended(
             'yPos2',
             [1.],
-            descr=_('List of fractional Y coordinates, dataset or '
-                    'expression for point 2'),
+            descr=_(
+                'List of fractional Y coordinates, dataset or '
+                'expression for point 2'),
             usertext=_('Y positions 2'),
             formatting=False), 7 )
 
-        s.add( setting.Bool('clip', False,
-                            descr=_('Clip line to its container'),
-                            usertext=_('Clip'),
-                            formatting=True), 0 )
+        s.add( setting.Bool(
+            'clip', False,
+            descr=_('Clip line to its container'),
+            usertext=_('Clip'),
+            formatting=True), 0 )
 
-        s.add( setting.Line('Line',
-                            descr = _('Line style'),
-                            usertext = _('Line')),
-               pixmap = 'settings_plotline' )
-        s.add( setting.ArrowFill('Fill',
-                                 descr = _('Arrow fill settings'),
-                                 usertext = _('Arrow fill')),
-               pixmap = 'settings_plotmarkerfill' )
+        s.add( setting.Line(
+            'Line',
+            descr=_('Line style'),
+            usertext=_('Line')),
+            pixmap='settings_plotline' )
+        s.add( setting.ArrowFill(
+            'Fill',
+            descr=_('Arrow fill settings'),
+            usertext=_('Arrow fill')),
+            pixmap='settings_plotmarkerfill' )
 
-        s.add( setting.DistancePt('arrowSize', '5pt',
-                                  descr = _('Size of arrow to plot'),
-                                  usertext=_('Arrow size'), formatting=True), 0)
-        s.add( setting.Arrow('arrowright', 'none',
-                             descr = _('Arrow to plot on right side'),
-                             usertext=_('Arrow right'), formatting=True), 0)
-        s.add( setting.Arrow('arrowleft', 'none',
-                             descr = _('Arrow to plot on left side'),
-                             usertext=_('Arrow left'), formatting=True), 0)
+        s.add( setting.DistancePt(
+            'arrowSize', '5pt',
+            descr=_('Size of arrow to plot'),
+            usertext=_('Arrow size'), formatting=True), 0)
+        s.add( setting.Arrow(
+            'arrowright', 'none',
+            descr=_('Arrow to plot on right side'),
+            usertext=_('Arrow right'), formatting=True), 0)
+        s.add( setting.Arrow(
+            'arrowleft', 'none',
+            descr=_('Arrow to plot on left side'),
+            usertext=_('Arrow left'), formatting=True), 0)
 
     def _computeLinesLengthAngle(self, posn, lengthscaling):
         """Return set of lines to plot for length-angle."""
@@ -139,7 +146,7 @@ class Line(plotters.FreePlotter):
             if len(angle) == 1: angle = itertools.cycle(angle)
 
         out = []
-        for v in czip(xpos, ypos, length, angle):
+        for v in zip(xpos, ypos, length, angle):
             # skip lines which have nans
             if N.all( N.isfinite(v) ):
                 out.append(v)
@@ -162,7 +169,7 @@ class Line(plotters.FreePlotter):
             if len(ypos2) == 1: ypos2 = itertools.cycle(ypos2)
 
         out = []
-        for v in czip(xpos, ypos, xpos2, ypos2):
+        for v in zip(xpos, ypos, xpos2, ypos2):
             # skip nans again
             if N.all( N.isfinite(v) ):
                 length = math.sqrt( (v[0]-v[2])**2 + (v[1]-v[3])**2 )
@@ -179,23 +186,27 @@ class Line(plotters.FreePlotter):
             return
 
         # if a dataset is used, we can't use control items
-        isnotdataset = ( not s.get('xPos').isDataset(d) and 
-                         not s.get('yPos').isDataset(d) )
+        isnotdataset = (
+            not s.get('xPos').isDataset(d) and
+            not s.get('yPos').isDataset(d) )
 
         if s.mode == 'length-angle':
-            isnotdataset = ( isnotdataset and
-                             not s.get('length').isDataset(d) and
-                             not s.get('angle').isDataset(d) )
+            isnotdataset = (
+                isnotdataset and
+                not s.get('length').isDataset(d) and
+                not s.get('angle').isDataset(d) )
         else:
-            isnotdataset = ( isnotdataset and
-                             not s.get('xPos2').isDataset(d) and
-                             not s.get('yPos2').isDataset(d) )
+            isnotdataset = (
+                isnotdataset and
+                not s.get('xPos2').isDataset(d) and
+                not s.get('yPos2').isDataset(d) )
 
         # now do the drawing
         clip = None
         if s.clip:
-            clip = qt4.QRectF( qt4.QPointF(posn[0], posn[1]),
-                               qt4.QPointF(posn[2], posn[3]) )
+            clip = qt.QRectF(
+                qt.QPointF(posn[0], posn[1]),
+                qt.QPointF(posn[2], posn[3]))
         painter = phelper.painter(self, posn, clip=clip)
         with painter:
             # adjustable positions for the lines
@@ -205,13 +216,13 @@ class Line(plotters.FreePlotter):
             if not s.Line.hide:
                 painter.setPen( s.get('Line').makeQPen(painter) )
             else:
-                painter.setPen( qt4.QPen(qt4.Qt.NoPen) )
+                painter.setPen( qt.QPen(qt.Qt.NoPen) )
 
             # settings for fill
             if not s.Fill.hide:
                 painter.setBrush( s.get('Fill').makeQBrush(painter) )
             else:
-                painter.setBrush( qt4.QBrush() )
+                painter.setBrush( qt.QBrush() )
 
             # iterate over positions
             scaling = posn[2]-posn[0]
@@ -226,10 +237,11 @@ class Line(plotters.FreePlotter):
             controlgraphitems = []
             for index, (x, y, l, a) in enumerate(lines):
 
-                utils.plotLineArrow(painter, x, y, l, a,
-                                    arrowsize=arrowsize,
-                                    arrowleft=s.arrowleft,
-                                    arrowright=s.arrowright)
+                utils.plotLineArrow(
+                    painter, x, y, l, a,
+                    arrowsize=arrowsize,
+                    arrowleft=s.arrowleft,
+                    arrowright=s.arrowright)
 
                 if isnotdataset:
                     cgi = controlgraph.ControlLine(
@@ -252,7 +264,12 @@ class Line(plotters.FreePlotter):
         if xpos is None or ypos is None:
             return
 
-        x, y = list(s.xPos), list(s.yPos)
+        x = s.get('xPos').getFloatArray(self.document)
+        y = s.get('yPos').getFloatArray(self.document)
+        if x is None or y is None:
+            return
+        x, y = list(x), list(y)
+
         idx = min(cgi.index, len(x)-1)
         if not N.allclose(x[idx], xpos[0]):
             x[idx] = utils.round2delt(xpos[0], xpos[1])
@@ -262,22 +279,29 @@ class Line(plotters.FreePlotter):
         operations = [
             document.OperationSettingSet(s.get('xPos'), x),
             document.OperationSettingSet(s.get('yPos'), y),
-            ]
+        ]
 
         if s.mode == 'length-angle':
             # convert 2nd point to length, angle
             def la(ptx, pty):
-                length = ( math.sqrt( (ptx-pt1[0])**2 + (pty-pt1[1])**2 ) /
-                           (cgi.widgetposn[2]-cgi.widgetposn[0]) )
-                angle = ( (math.atan2( pty-pt1[1], ptx-pt1[0] )
-                           * 180. / math.pi) % 360. )
+                length = (
+                    math.sqrt( (ptx-pt1[0])**2 + (pty-pt1[1])**2 ) /
+                    (cgi.widgetposn[2]-cgi.widgetposn[0]) )
+                angle = (
+                    (math.atan2( pty-pt1[1], ptx-pt1[0] ) *
+                     180. / math.pi) % 360. )
                 return length, angle
             length, angle = la(pt2[0], pt2[1])
             # calculate length angle for neighbouring point, to get delta
             ldelt, adelt = la(pt2[0]+1, pt2[1]+1)
 
             # update values
-            l, a = list(s.length), list(s.angle)
+            l = s.get('length').getFloatArray(self.document)
+            a = s.get('angle').getFloatArray(self.document)
+            if l is None or a is None:
+                return
+            l, a = list(l), list(a)
+
             idx = min(cgi.index, len(l)-1)
             if abs(l[idx]-length) > 1e-8:
                 l[idx] = utils.round2delt(length, ldelt)
@@ -288,12 +312,16 @@ class Line(plotters.FreePlotter):
             operations += [
                 document.OperationSettingSet(s.get('length'), l),
                 document.OperationSettingSet(s.get('angle'), a),
-                ]
+            ]
         else:
             xpos2, ypos2 = self._getGraphCoords(
                 cgi.widgetposn, [pt2[0], pt2[0]+1], [pt2[1], pt2[1]+1])
             if xpos2 is not None and ypos2 is not None:
-                x2, y2 = list(s.xPos2), list(s.yPos2)
+                x2 = s.get('xPos2').getFloatArray(self.document)
+                y2 = s.get('yPos2').getFloatArray(self.document)
+                if x2 is None or y2 is None:
+                    return
+                x2, y2 = list(x2), list(y2)
 
                 idx = min(cgi.index, len(x2)-1)
                 if not N.allclose(x2[idx], xpos2[0]):
@@ -305,9 +333,9 @@ class Line(plotters.FreePlotter):
                 operations += [
                     document.OperationSettingSet(s.get('xPos2'), x2),
                     document.OperationSettingSet(s.get('yPos2'), y2)
-                    ]
+                ]
 
         self.document.applyOperation(
             document.OperationMultiple(operations, descr=_('adjust lines')) )
 
-document.thefactory.register( Line )
+document.thefactory.register(Line)
