@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright (C) 2004 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -20,9 +19,9 @@
 """Window to edit the document using a tree, widget properties
 and formatting properties."""
 
-from __future__ import division
+import os
+import tempfile
 
-from ..compat import crange, citems
 from .. import qtall as qt
 
 from .. import widgets
@@ -36,7 +35,7 @@ def _(text, disambiguation=None, context='TreeEditWindow'):
     """Translate text."""
     return qt.QCoreApplication.translate(context, text, disambiguation)
 
-class SettingsProxy(object):
+class SettingsProxy:
     """Object to handle communication between widget/settings
     or sets of widgets/settings."""
 
@@ -58,6 +57,7 @@ class SettingsProxy(object):
     def onAction(self, action, console):
         """Called if action pressed. Console window is given."""
 
+    @property
     def name(self):
         """Return name of Settings."""
 
@@ -101,8 +101,10 @@ class SettingsProxySingle(SettingsProxy):
 
     def settingsProxyList(self):
         """Return list of SettingsProxy objects."""
-        return [ SettingsProxySingle(self.document, s)
-                 for s in self.settings.getSettingsList() ]
+        return [
+            SettingsProxySingle(self.document, s)
+            for s in self.settings.getSettingsList()
+        ]
 
     def settingList(self):
         """Return list of Setting objects."""
@@ -122,6 +124,7 @@ class SettingsProxySingle(SettingsProxy):
         """Run action on console."""
         console.runFunction(action.function)
 
+    @property
     def name(self):
         """Return name."""
         return self.settings.name
@@ -198,8 +201,8 @@ class SettingsProxyMulti(SettingsProxy):
                 newroot = n
                 if self._root:
                     newroot = self._root + '/' + newroot
-                v = SettingsProxyMulti(self.document, self.widgets,
-                                       _root=newroot)
+                v = SettingsProxyMulti(
+                    self.document, self.widgets, _root=newroot)
             else:
                 # use setting from first settings as template
                 v = o
@@ -210,8 +213,8 @@ class SettingsProxyMulti(SettingsProxy):
     def childProxyList(self):
         """Make a list of proxy settings."""
         if self._cachechild is None:
-            self._cachechild = self._objList( (setting.Settings,
-                                               setting.Setting) )
+            self._cachechild = self._objList(
+                (setting.Settings, setting.Setting) )
         return self._cachechild
 
     def settingsProxyList(self):
@@ -262,6 +265,7 @@ class SettingsProxyMulti(SettingsProxy):
                 if a.name == aname:
                     console.runFunction(a.function)
 
+    @property
     def name(self):
         return self._settingsatlevel[0].name
 
@@ -295,6 +299,44 @@ class SettingsProxyMulti(SettingsProxy):
         self.document.applyOperation(
             document.OperationMultiple(ops, descr=_("reset to default")))
 
+class VisibilityButton(qt.QPushButton):
+    """Button for toggling 'hide' settings."""
+
+    def __init__(self, setnsproxy, setn, *args, **argsv):
+        qt.QPushButton.__init__(self, *args, **argsv)
+        self.setContentsMargins(0,0,0,0)
+        self.setSizePolicy(
+            qt.QSizePolicy.Minimum, qt.QSizePolicy.Minimum)
+        self.setIconSize(qt.QSize(24,12))
+        self.setFlat(True)
+        self.setFocusPolicy(qt.Qt.NoFocus)
+
+        self.setnsproxy = setnsproxy
+        self.setn = setn
+
+        setn.setOnModified(self.updateIcon)
+
+        self.updateIcon()
+        self.clicked.connect(self.onClicked)
+
+    def updateIcon(self):
+        """Update state given current setting."""
+        hidden = self.setn.get()
+        if hidden:
+            icon = 'veusz-eye-grey'
+            tooltip = _('Hidden (click to show; set hide to False)')
+        else:
+            icon = 'veusz-eye'
+            tooltip = _('Visible (click to hide; set hide to True)')
+
+        self.setIcon(utils.getIcon(icon))
+        self.setToolTip(tooltip)
+
+    def onClicked(self):
+        """Toggle the setting."""
+        hidden = self.setn.get()
+        self.setnsproxy.onSettingChanged(None, self.setn, not hidden)
+
 class PropertyList(qt.QWidget):
     """Edit the widget properties using a set of controls."""
 
@@ -441,14 +483,31 @@ class PropertyList(qt.QWidget):
         self.setncntrls = {}
         self.layout.setEnabled(False)
 
+        # list of settings to show
+        setlist = setnsproxy.childProxyList()
+        names = [x.name for x in setlist]
+
+        # we special case hide by always showing it at the top
+        hideidx = utils.listIndex(names, 'hide')
+
         # add a title if requested
         if title is not None:
-            lab = qt.QLabel(
-                title[0],
-                frameShape=qt.QFrame.Panel,
-                frameShadow=qt.QFrame.Sunken,
-                toolTip=title[1] )
-            self.layout.addWidget(lab, row, 0, 1, -1)
+            lab = qt.QLabel(title[0], toolTip=title[1])
+            lab.setSizePolicy(
+                qt.QSizePolicy.Expanding, qt.QSizePolicy.Minimum)
+
+            titlewidget = qt.QFrame(
+                frameShape=qt.QFrame.Panel, frameShadow=qt.QFrame.Sunken)
+            titlelayout = qt.QHBoxLayout()
+            titlelayout.setSpacing(0)
+            if hideidx >= 0:
+                button = VisibilityButton(setnsproxy, setlist[hideidx])
+                titlelayout.addWidget(button)
+            titlelayout.addWidget(lab)
+            titlelayout.setContentsMargins(0,0,0,0)
+            titlewidget.setLayout(titlelayout)
+
+            self.layout.addWidget(titlewidget, row, 0, 1, -1)
             row += 1
 
         # add actions if parent is widget
@@ -462,12 +521,11 @@ class PropertyList(qt.QWidget):
             row += 1
             self.childlist.append(tabbed)
         else:
-            # else add settings proper as a list
-            for setn in setnsproxy.childProxyList():
 
-                # add setting
+            def addrow(setn):
                 # only add if formatting setting and formatting allowed
                 # and not formatting and not formatting not allowed
+                nonlocal row
                 if ( isinstance(setn, setting.Setting) and (
                         (setn.formatting and (showformatting or onlyformatting))
                         or (not setn.formatting and not onlyformatting)) and
@@ -478,6 +536,14 @@ class PropertyList(qt.QWidget):
                        not onlyformatting ):
                     row = self._addGroupedSettingsControl(setn, row)
 
+            # else add settings proper as a list
+            for name, setn in zip(names, setlist):
+                if name != 'hide':
+                    addrow(setn)
+
+            if hideidx >= 0:
+                addrow(setlist[hideidx])
+
         # add empty widget to take rest of space
         w = qt.QWidget( sizePolicy=qt.QSizePolicy(
             qt.QSizePolicy.Maximum, qt.QSizePolicy.MinimumExpanding) )
@@ -511,8 +577,8 @@ class TabbedFormatting(qt.QTabWidget):
         setnslist = setnsproxy.settingsProxyList()
 
         # add formatting settings if necessary
-        numformat = len( [setn for setn in setnsproxy.settingList()
-                          if setn.formatting] )
+        numformat = len(
+            [setn for setn in setnsproxy.settingList() if setn.formatting] )
         if numformat > 0:
             # add on a formatting tab
             setnslist.insert(0, setnsproxy)
@@ -529,12 +595,21 @@ class TabbedFormatting(qt.QTabWidget):
         # tabs which have been initialized
         self.tabinit = set()
 
-        # add tab for each subsettings
+        # for modifiying tab icons depending on hidden status
+        hide_mapper = qt.QSignalMapper(self)
+        self.hide_map = {}
+
         for subset in setnslist:
             if subset.setnsmode() not in ('formatting', 'widgetsettings'):
                 continue
             self.tabsubsetns.append(subset)
 
+            hidesetn = None
+            for s in subset.settingList():
+                if s.name == 'hide':
+                    hidesetn = s
+                    break
+
             # details of tab
             if subset is setnsproxy:
                 # main tab formatting, so this is special
@@ -547,7 +622,7 @@ class TabbedFormatting(qt.QTabWidget):
                     pixmap = subset.pixmap()
                 else:
                     pixmap = None
-                tabname = subset.name()
+                tabname = subset.name
                 tooltip = title = subset.usertext()
 
             # hide name in tab
@@ -558,9 +633,29 @@ class TabbedFormatting(qt.QTabWidget):
             self.tabtooltips.append(tooltip)
 
             # create tab
-            indx = self.addTab(qt.QWidget(), utils.getIcon(pixmap), tabname)
+            indx = self.addTab(qt.QWidget(), tabname)
+
+            # tab icon updates to visible/invisible depending on
+            # whether subsetting is hidden or not
+            if hidesetn is not None:
+                hidesetn.onmodified.onModified.connect(
+                    hide_mapper.map)
+                hide_mapper.setMapping(hidesetn.onmodified, indx)
+
+            self.hide_map[indx] = (pixmap, hidesetn)
+            self.updateIcon(indx)
             self.setTabToolTip(indx, tooltip)
 
+        hide_mapper.mapped[int].connect(self.updateIcon)
+
+    def updateIcon(self, indx):
+        """Update icon for tab, depending on status of hide setting."""
+        pixmap, hidesetn = self.hide_map[indx]
+        icon = utils.getIcon(pixmap)
+        if hidesetn is not None and hidesetn.get():
+            icon = qt.QIcon(utils.DisabledIconEngine(icon))
+        self.setTabIcon(indx, icon)
+
     def slotCurrentChanged(self, tab):
         """Lazy loading of tab when displayed."""
         if tab in self.tabinit:
@@ -685,14 +780,14 @@ class TreeEditDock(qt.QDockWidget):
         self.setWidget(self.treeview)
 
         # toolbar to create widgets
-        self.addtoolbar = qt.QToolBar(_("Insert toolbar - Veusz"),
-                                       parentwin)
+        self.addtoolbar = qt.QToolBar(
+            _("Insert toolbar - Veusz"), parentwin)
         # note wrong description!: backwards compatibility
         self.addtoolbar.setObjectName("veuszeditingtoolbar")
 
         # toolbar for editting widgets
-        self.edittoolbar = qt.QToolBar(_("Edit toolbar - Veusz"),
-                                        parentwin)
+        self.edittoolbar = qt.QToolBar(
+            _("Edit toolbar - Veusz"), parentwin)
         self.edittoolbar.setObjectName("veuszedittoolbar")
 
         self._constructToolbarMenu()
@@ -720,7 +815,7 @@ class TreeEditDock(qt.QDockWidget):
 
         # actions on widget(s)
         for act in (
-                'edit.cut', 'edit.copy', 'edit.paste',
+                'edit.cut', 'edit.copy', 'edit.copy_as_image', 'edit.paste',
                 'edit.moveup', 'edit.movedown', 'edit.delete',
                 'edit.rename'
         ):
@@ -794,7 +889,7 @@ class TreeEditDock(qt.QDockWidget):
 
         # check whether each button can have this widget
         # (or a parent) as parent
-        for wc, action in citems(self.addslots):
+        for wc, action in self.addslots.items():
             w = selw
             while w is not None and not wc.willAllowParent(w):
                 w = w.parent
@@ -824,7 +919,7 @@ class TreeEditDock(qt.QDockWidget):
         isnotroot = not any([isinstance(w, widgets.Root)
                              for w in self.selwidgets])
 
-        for act in ('edit.cut', 'edit.copy', 'edit.delete',
+        for act in ('edit.cut', 'edit.copy', 'edit.copy_as_image', 'edit.delete',
                     'edit.moveup', 'edit.movedown', 'edit.rename'):
             self.vzactions[act].setEnabled(isnotroot)
 
@@ -857,7 +952,7 @@ class TreeEditDock(qt.QDockWidget):
                 'xy', 'bar', 'histo', 'fit', 'function', 'boxplot',
                 'image', 'contour', 'vectorfield',
                 'key', 'label', 'colorbar',
-                'rect', 'ellipse', 'imagefile',
+                'rect', 'ellipse', 'imagefile', 'svgfile',
                 'line', 'polygon', 'polar', 'ternary',
                 'nonorthpoint', 'nonorthfunc',
                 'covariance',
@@ -879,54 +974,57 @@ class TreeEditDock(qt.QDockWidget):
 
         a = utils.makeAction
         actions.update({
-                'edit.cut':
-                    a(self, _('Cut the selected widget'), _('Cu&t'),
-                      self.slotWidgetCut,
-                      icon='veusz-edit-cut', key='Ctrl+X'),
-                'edit.copy':
-                    a(self, _('Copy the selected widget'), _('&Copy'),
-                      self.slotWidgetCopy,
-                      icon='kde-edit-copy', key='Ctrl+C'),
-                'edit.paste':
-                    a(self, _('Paste widget from the clipboard'), _('&Paste'),
-                      self.slotWidgetPaste,
-                      icon='kde-edit-paste', key='Ctrl+V'),
-                'edit.moveup':
-                    a(self, _('Move the selected widget up'), _('Move &up'),
-                      lambda: self.slotWidgetMove(-1),
-                      icon='kde-go-up', key='Ctrl+PgUp'),
-                'edit.movedown':
-                    a(self, _('Move the selected widget down'), _('Move d&own'),
-                      lambda: self.slotWidgetMove(1),
-                      icon='kde-go-down', key='Ctrl+PgDown'),
-                'edit.delete':
-                    a(self, _('Remove the selected widget'), _('&Delete'),
-                      self.slotWidgetDelete,
-                      icon='kde-edit-delete'),
-                'edit.rename':
-                    a(self, _('Renames the selected widget'), _('&Rename'),
-                      self.slotWidgetRename,
-                      icon='kde-edit-rename'),
-                'edit.show':
-                    a(self, _('Show selected widget(s)'), _('Show'),
-                      self.slotWidgetShow,
-                      key='Ctrl+]'),
-                'edit.hide':
-                    a(self, _('Hide selected widget(s)'), _('Hide'),
-                      self.slotWidgetHide,
-                      key='Ctrl+['),
+            'edit.cut': a(
+                self, _('Cut the selected widget'), _('Cu&t'),
+                self.slotWidgetCut,
+                icon='veusz-edit-cut', key='Ctrl+X'),
+            'edit.copy': a(
+                self, _('Copy the selected widget'), _('&Copy'),
+                self.slotWidgetCopy,
+                icon='kde-edit-copy', key='Ctrl+C'),
+            'edit.copy_as_image': a(
+                self, _('Copy the current page as svg image'), _('&Copy as Image'),
+                self.slotWidgetCopyAsImage,
+                icon='kde-edit-copy', key='Ctrl+Alt+C'),
+            'edit.paste': a(
+                self, _('Paste widget from the clipboard'), _('&Paste'),
+                self.slotWidgetPaste,
+                icon='kde-edit-paste', key='Ctrl+V'),
+            'edit.moveup': a(
+                self, _('Move the selected widget up'), _('Move &up'),
+                lambda: self.slotWidgetMove(-1),
+                icon='kde-go-up', key='Ctrl+Shift+PgUp'),
+            'edit.movedown': a(
+                self, _('Move the selected widget down'), _('Move d&own'),
+                lambda: self.slotWidgetMove(1),
+                icon='kde-go-down', key='Ctrl+Shift+PgDown'),
+            'edit.delete': a(
+                self, _('Remove the selected widget'), _('&Delete'),
+                self.slotWidgetDelete,
+                icon='kde-edit-delete'),
+            'edit.rename': a(
+                self, _('Renames the selected widget'), _('&Rename'),
+                self.slotWidgetRename,
+                icon='kde-edit-rename'),
+            'edit.show': a(
+                self, _('Show selected widget(s)'), _('Show'),
+                self.slotWidgetShow,
+                key='Ctrl+]'),
+            'edit.hide': a(
+                self, _('Hide selected widget(s)'), _('Hide'),
+                self.slotWidgetHide,
+                key='Ctrl+['),
 
-                'add.shapemenu':
-                    a(self, _('Add a shape to the plot'), _('Shape'),
-                      self.slotShowShapeMenu,
-                      icon='veusz-shape-menu'),
+            'add.shapemenu': a(
+                self, _('Add a shape to the plot'), _('Shape'),
+                self.slotShowShapeMenu,
+                icon='veusz-shape-menu'),
 
-                'add.axismenu':
-                    a(self, _('Add an axis to the plot'), _('Axis'),
-                      None,
-                      icon='button_axis'),
-
-                })
+            'add.axismenu': a(
+                self, _('Add an axis to the plot'), _('Axis'),
+                None,
+                icon='button_axis'),
+        })
 
         # list of widget-generating actions for menu and toolbar
         widgetactions = (
@@ -959,55 +1057,63 @@ class TreeEditDock(qt.QDockWidget):
             'add.graph3d',
             'add.covariance',
             'add.shapemenu',
-            )
+        )
 
         # separate menus for adding shapes and axis types
         shapemenu = qt.QMenu()
         shapemenu.addActions( [actions[act] for act in (
-                    'add.rect',
-                    'add.ellipse',
-                    'add.line',
-                    'add.imagefile',
-                    'add.polygon',
-                    )])
+            'add.rect',
+            'add.ellipse',
+            'add.line',
+            'add.imagefile',
+            'add.svgfile',
+            'add.polygon',
+        )])
         actions['add.shapemenu'].setMenu(shapemenu)
 
         axismenu = qt.QMenu()
         axismenu.addActions( [actions[act] for act in (
-                    'add.axis',
-                    'add.axis-broken',
-                    'add.axis-function',
-             )])
+            'add.axis',
+            'add.axis-broken',
+            'add.axis-function',
+        )])
         actions['add.axismenu'].setMenu(axismenu)
         actions['add.axismenu'].triggered.connect(actions['add.axis'].trigger)
 
         menuitems = (
             ('insert', '', widgetactions),
             ('edit', '', (
-                    'edit.cut',
-                    'edit.copy',
-                    'edit.paste',
-                    'edit.delete',
-                    'edit.rename',
-                    'edit.moveup',
-                    'edit.movedown',
-                    'edit.show',
-                    'edit.hide',
-                    )),
-            )
-        utils.constructMenus( self.parentwin.menuBar(),
-                              self.parentwin.menus,
-                              menuitems,
-                              actions )
+                'edit.cut',
+                'edit.copy',
+                'edit.copy_as_image',
+                'edit.paste',
+                'edit.delete',
+                'edit.rename',
+                'edit.moveup',
+                'edit.movedown',
+                'edit.show',
+                'edit.hide',
+            )),
+        )
+        utils.constructMenus(
+            self.parentwin.menuBar(),
+            self.parentwin.menus,
+            menuitems,
+            actions
+        )
 
         # add actions to toolbar to create widgets
         utils.addToolbarActions(self.addtoolbar, actions, widgetactions)
 
         # add action to toolbar for editing
-        utils.addToolbarActions(self.edittoolbar,  actions,
-                                ('edit.cut', 'edit.copy', 'edit.paste',
-                                 'edit.moveup', 'edit.movedown',
-                                 'edit.delete', 'edit.rename'))
+        utils.addToolbarActions(
+            self.edittoolbar,  actions,
+            (
+                'edit.cut', 'edit.copy', 'edit.paste',
+                'edit.moveup', 'edit.movedown',
+                'edit.delete', 'edit.rename',
+            )
+        )
 
         self.parentwin.menus['edit.select'].aboutToShow.connect(
             self.updateSelectMenu)
@@ -1039,8 +1145,8 @@ class TreeEditDock(qt.QDockWidget):
 
         # make the new widget and update the document
         w = self.document.applyOperation(
-            document.OperationWidgetAdd(parent, widgettype, autoadd=autoadd,
-                                        name=name) )
+            document.OperationWidgetAdd(
+                parent, widgettype, autoadd=autoadd, name=name) )
 
         # select the widget
         self.selectWidget(w)
@@ -1061,6 +1167,70 @@ class TreeEditDock(qt.QDockWidget):
             clipboard = qt.QApplication.clipboard()
             clipboard.setMimeData(mimedata)
 
+    def slotWidgetCopyAsImage(self):
+        """Copy current page to the clipboard as image files."""
+        # general image extentions and their mime types exportable from document
+        exts = {'svg': ['image/svg+xml'],
+                'png': ['image/png', 'PNG'],
+                'bmp': ['image/x-bmp'],
+                }
+
+        def checkDone(export, exts):
+            """Check whether exporting pages as images has finished."""
+            if not export.haveDone():
+                return
+            try:
+                export.finish()
+                clipboard = qt.QApplication.clipboard()
+                data = qt.QMimeData()
+
+                # set images to QMimeData
+                for ext, mimes in exts.items():
+                    try:
+                        fname = os.path.join(tmpdir.name, 'tmp.{}'.format(ext))
+                        with open(fname, 'rb') as fo:
+                            bs = fo.read()
+                        for mime in mimes:
+                            data.setData(mime, bs)
+                        os.remove(fname)
+                    except:
+                        pass
+
+                # set QMimeData to clipboard
+                clipboard.setMimeData(data)
+                tmpdir.cleanup()
+
+            except:
+                qt.QMessageBox.critical(self, _("Error - Veusz"), _("Error while exporting images"))
+            self.checktimer.stop()
+
+        # read settings from settingdb
+        setdb = setting.settingdb
+        export = document.AsyncExport(
+            self.document,
+            bitmapdpi=setdb['export_DPI'],
+            pdfdpi=setdb['export_DPI_PDF'],
+            antialias=setdb['export_antialias'],
+            color=setdb['export_color'],
+            quality=setdb['export_quality'],
+            backcolor=setdb['export_background'],
+            svgtextastext=setdb['export_SVG_text_as_text'],
+            svgdpi=setdb['export_DPI_SVG'],
+        )
+
+        tmpdir = tempfile.TemporaryDirectory()
+        pages = [self.parentwin.plot.getPageNumber()]
+
+        # export images to temporary files
+        for ext in exts:
+            fname = os.path.join(tmpdir.name, 'tmp.{}'.format(ext))
+            export.add(fname, pages)
+
+        # copy images to clipboard after finishing export
+        self.checktimer = qt.QTimer(self)
+        self.checktimer.timeout.connect(lambda: checkDone(export, exts))
+        self.checktimer.start(20)
+
     def updatePasteButton(self):
         """Is the data on the clipboard a valid paste at the currently
         selected widget? If so, enable paste button"""
@@ -1075,7 +1245,7 @@ class TreeEditDock(qt.QDockWidget):
     def doInitialWidgetSelect(self):
         """Select a sensible initial widget."""
         w = self.document.basewidget
-        for i in crange(2):
+        for i in range(2):
             try:
                 c = w.children[0]
             except IndexError:
@@ -1406,8 +1576,8 @@ class SettingLabel(qt.QWidget):
         setwidget = self.setting.getWidget()
         if setwidget is None:
             return
-        getWidgetsOfType(self.document.basewidget,
-                         setwidget.typename, widgets)
+        getWidgetsOfType(
+            self.document.basewidget, setwidget.typename, widgets)
         widgets = [w.path for w in widgets if w != setwidget]
         widgets.sort()
 
@@ -1500,16 +1670,18 @@ class SettingLabel(qt.QWidget):
     def actionCopyTypedSiblings(self):
         """Copy setting to siblings of the same type."""
         self.document.applyOperation(
-            document.OperationSettingPropagate(self.setting,
-                                               root=self._clickwidget.parent,
-                                               maxlevels=1) )
+            document.OperationSettingPropagate(
+                self.setting,
+                root=self._clickwidget.parent,
+                maxlevels=1) )
 
     def actionCopyTypedNamedWidgets(self):
         """Copy setting to widgets with the same name and type."""
         self.document.applyOperation(
-            document.OperationSettingPropagate(self.setting,
-                                               widgetname=
-                                               self._clickwidget.name) )
+            document.OperationSettingPropagate(
+                self.setting,
+                widgetname=
+                self._clickwidget.name) )
 
     def actionUnlinkSetting(self):
         """Unlink the setting if it is a reference."""
@@ -1524,8 +1696,10 @@ class SettingLabel(qt.QWidget):
         # apply operation to change it
         self.document.applyOperation(
             document.OperationMultiple(
-                [ document.OperationSettingSet(sslink, self.setting.get()),
-                  document.OperationSettingSet(self.setting,
-                                               self.setting.default) ],
+                [
+                    document.OperationSettingSet(sslink, self.setting.get()),
+                    document.OperationSettingSet(
+                        self.setting, self.setting.default)
+                ],
                 descr=_("make default style"))
-            )
+        )
